==> com.liferay.layout.admin.web-3.0.23.jar: META-INF/resources/js/DisplayPageDropdownDefaultEventHandler.es.js <==
"use strict";

Liferay.Loader.define("layout-admin-web@3.0.23/js/DisplayPageDropdownDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web/liferay/modal/commands/OpenSimpleInputModal.es', 'frontend-js-web/liferay/DefaultEventHandler.es', 'frontend-js-metal-web$metal-state'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = void 0;

  var _OpenSimpleInputModal = _interopRequireDefault(require("frontend-js-web/liferay/modal/commands/OpenSimpleInputModal.es"));

  var _DefaultEventHandler2 = _interopRequireDefault(require("frontend-js-web/liferay/DefaultEventHandler.es"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var DisplayPageDropdownDefaultEventHandler =
  /*#__PURE__*/
  function (_DefaultEventHandler) {
    _inherits(DisplayPageDropdownDefaultEventHandler, _DefaultEventHandler);

    function DisplayPageDropdownDefaultEventHandler() {
      _classCallCheck(this, DisplayPageDropdownDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(DisplayPageDropdownDefaultEventHandler).apply(this, arguments));
    }

    _createClass(DisplayPageDropdownDefaultEventHandler, [{
      key: "deleteDisplayPage",
      value: function deleteDisplayPage(itemData) {
        if (confirm(Liferay.Language.get('are-you-sure-you-want-to-delete-this'))) {
          this._send(itemData.deleteDisplayPageURL);
        }
      }
    }, {
      key: "markAsDefaultDisplayPage",
      value: function markAsDefaultDisplayPage(itemData) {
        if (itemData.message !== '') {
          if (confirm(Liferay.Language.get(itemData.message))) {
            this._send(itemData.markAsDefaultDisplayPageURL);
          }
        } else {
          this._send(itemData.markAsDefaultDisplayPageURL);
        }
      }
    }, {
      key: "permissionsDisplayPage",
      value: function permissionsDisplayPage(itemData) {
        Liferay.Util.openWindow({
          dialog: {
            destroyOnHide: true,
            modal: true
          },
          dialogIframe: {
            bodyCssClass: 'dialog-with-footer'
          },
          title: Liferay.Language.get('permissions'),
          uri: itemData.permissionsDisplayPageURL
        });
      }
    }, {
      key: "renameDisplayPage",
      value: function renameDisplayPage(itemData) {
        (0, _OpenSimpleInputModal.default)({
          dialogTitle: Liferay.Language.get('rename-display-page-template'),
          formSubmitURL: itemData.updateDisplayPageURL,
          idFieldName: 'layoutPageTemplateEntryId',
          idFieldValue: itemData.layoutPageTemplateEntryId,
          mainFieldLabel: Liferay.Language.get('name'),
          mainFieldName: 'name',
          mainFieldPlaceholder: Liferay.Language.get('name'),
          mainFieldValue: itemData.layoutPageTemplateEntryName,
          namespace: this.namespace,
          spritemap: this.spritemap
        });
      }
    }, {
      key: "unmarkAsDefaultDisplayPage",
      value: function unmarkAsDefaultDisplayPage(itemData) {
        if (confirm(Liferay.Language.get('unmark-default-confirmation'))) {
          this._send(itemData.unmarkAsDefaultDisplayPageURL);
        }
      }
    }, {
      key: "_send",
      value: function _send(url) {
        submitForm(document.hrefFm, url);
      }
    }]);

    return DisplayPageDropdownDefaultEventHandler;
  }(_DefaultEventHandler2.default);

  DisplayPageDropdownDefaultEventHandler.STATE = {
    spritemap: _metalState.Config.string()
  };
  var _default = DisplayPageDropdownDefaultEventHandler;
  exports.default = _default;
  //# sourceMappingURL=DisplayPageDropdownDefaultEventHandler.es.js.map
});
//# sourceMappingURL=DisplayPageDropdownDefaultEventHandler.es.js.map

==> com.liferay.layout.admin.web-3.0.87.jar: META-INF/resources/js/DisplayPageDropdownDefaultEventHandler.es.js <==
Liferay.Loader.define("layout-admin-web@3.0.87/js/DisplayPageDropdownDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web', 'frontend-js-metal-web$metal-state'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  var _metalState = require("frontend-js-metal-web$metal-state");

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var DisplayPageDropdownDefaultEventHandler = /*#__PURE__*/function (_DefaultEventHandler) {
    _inherits(DisplayPageDropdownDefaultEventHandler, _DefaultEventHandler);

    function DisplayPageDropdownDefaultEventHandler() {
      _classCallCheck(this, DisplayPageDropdownDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(DisplayPageDropdownDefaultEventHandler).apply(this, arguments));
    }

    _createClass(DisplayPageDropdownDefaultEventHandler, [{
      key: "deleteDisplayPage",
      value: function deleteDisplayPage(itemData) {
        if (confirm(Liferay.Language.get('are-you-sure-you-want-to-delete-this'))) {
          this._send(itemData.deleteDisplayPageURL);
        }
      }
    }, {
      key: "markAsDefaultDisplayPage",
      value: function markAsDefaultDisplayPage(itemData) {
        if (itemData.message !== '') {
          if (confirm(Liferay.Language.get(itemData.message))) {
            this._send(itemData.markAsDefaultDisplayPageURL);
          }
        } else {
          this._send(itemData.markAsDefaultDisplayPageURL);
        }
      }
    }, {
      key: "permissionsDisplayPage",
      value: function permissionsDisplayPage(itemData) {
        Liferay.Util.openWindow({
          dialog: {
            destroyOnHide: true,
            modal: true
          },
          dialogIframe: {
            bodyCssClass: 'dialog-with-footer'
          },
          title: Liferay.Language.get('permissions'),
          uri: itemData.permissionsDisplayPageURL
        });
      }
    }, {
      key: "renameDisplayPage",
      value: function renameDisplayPage(itemData) {
        (0, _frontendJsWeb.openSimpleInputModal)({
          dialogTitle: Liferay.Language.get('rename-display-page-template'),
          formSubmitURL: itemData.updateDisplayPageURL,
          idFieldName: 'layoutPageTemplateEntryId',
          idFieldValue: itemData.layoutPageTemplateEntryId,
          mainFieldLabel: Liferay.Language.get('name'),
          mainFieldName: 'name',
          mainFieldPlaceholder: Liferay.Language.get('name'),
          mainFieldValue: itemData.layoutPageTemplateEntryName,
          namespace: this.namespace,
          spritemap: this.spritemap
        });
      }
    }, {
      key: "unmarkAsDefaultDisplayPage",
      value: function unmarkAsDefaultDisplayPage(itemData) {
        if (confirm(Liferay.Language.get('unmark-default-confirmation'))) {
          this._send(itemData.unmarkAsDefaultDisplayPageURL);
        }
      }
    }, {
      key: "_send",
      value: function _send(url) {
        submitForm(document.hrefFm, url);
      }
    }]);

    return DisplayPageDropdownDefaultEventHandler;
  }(_frontendJsWeb.DefaultEventHandler);

  DisplayPageDropdownDefaultEventHandler.STATE = {
    spritemap: _metalState.Config.string()
  };
  var _default = DisplayPageDropdownDefaultEventHandler;
  exports["default"] = _default;
  //# sourceMappingURL=DisplayPageDropdownDefaultEventHandler.es.js.map
});
//# sourceMappingURL=DisplayPageDropdownDefaultEventHandler.es.js.map
